==> jc-1.4.0.tar.gz: java/net/InetSocketAddress.h <==
// public class java.net.InetSocketAddress

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a431c217c7840ef0 java_net_InetSocketAddress
// @dep_class 45e49f95a1f57a78 java_net_SocketAddress

// header file dependencies
// @dep_header java_net_SocketAddress

#include "java/net/SocketAddress.h"

#ifndef _JC_java_net_InetSocketAddress_H_
#define _JC_java_net_InetSocketAddress_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_InetAddress$object;

// Typedefs
typedef struct _jc_java_net_InetSocketAddress$sub_refs	_jc_java_net_InetSocketAddress$sub_refs;
typedef struct _jc_java_net_InetSocketAddress$sub_nonrefs	_jc_java_net_InetSocketAddress$sub_nonrefs;
typedef struct _jc_java_net_InetSocketAddress$refs	_jc_java_net_InetSocketAddress$refs;
typedef struct _jc_java_net_InetSocketAddress$nonrefs	_jc_java_net_InetSocketAddress$nonrefs;
typedef struct _jc_java_net_InetSocketAddress$object	_jc_java_net_InetSocketAddress$object;

typedef struct _jc_java_net_InetSocketAddress$fields_struct	_jc_java_net_InetSocketAddress$fields_struct;
typedef const struct _jc_java_net_InetSocketAddress$vmethods	_jc_java_net_InetSocketAddress$vmethods;
typedef const struct _jc_java_net_InetSocketAddress$vtable	_jc_java_net_InetSocketAddress$vtable;
typedef const struct _jc_java_net_InetSocketAddress$vtype	_jc_java_net_InetSocketAddress$vtype;

// Class fields structure
struct _jc_java_net_InetSocketAddress$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_net_InetSocketAddress$fields_struct _jc_java_net_InetSocketAddress$class_fields;

// Constructors
extern void _jc_java_net_InetSocketAddress$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_net_InetSocketAddress$object *, jint);
extern void _jc_java_net_InetSocketAddress$method$_init$8b03e78e1eb3b29e(_jc_env *, struct _jc_java_net_InetSocketAddress$object *, struct _jc_java_lang_String$object *, jint);
extern void _jc_java_net_InetSocketAddress$method$_init$0cb3d434db3c104e(_jc_env *, struct _jc_java_net_InetSocketAddress$object *, struct _jc_java_net_InetAddress$object *, jint);

// Virtual methods
extern jboolean _jc_java_net_InetSocketAddress$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_net_InetSocketAddress$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_net_InetAddress$object *_jc_java_net_InetSocketAddress$method$getAddress$1fb94530641aa9d0(_jc_env *, struct _jc_java_net_InetSocketAddress$object *);
extern struct _jc_java_lang_String$object *_jc_java_net_InetSocketAddress$method$getHostName$668f39cc56f1375b(_jc_env *, struct _jc_java_net_InetSocketAddress$object *);
extern jint _jc_java_net_InetSocketAddress$method$getPort$e10115a3e6b3cead(_jc_env *, struct _jc_java_net_InetSocketAddress$object *);
extern jint _jc_java_net_InetSocketAddress$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_net_InetSocketAddress$object *);
extern jboolean _jc_java_net_InetSocketAddress$method$isUnresolved$3cc3ff5bd599bfe4(_jc_env *, struct _jc_java_net_InetSocketAddress$object *);
extern struct _jc_java_lang_String$object *_jc_java_net_InetSocketAddress$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_net_InetSocketAddress$object *);

// Virtual method descriptors
extern _jc_method _jc_java_net_InetSocketAddress$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_net_InetSocketAddress$method_info$getAddress$1fb94530641aa9d0;
extern _jc_method _jc_java_net_InetSocketAddress$method_info$getHostName$668f39cc56f1375b;
extern _jc_method _jc_java_net_InetSocketAddress$method_info$getPort$e10115a3e6b3cead;
extern _jc_method _jc_java_net_InetSocketAddress$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_net_InetSocketAddress$method_info$isUnresolved$3cc3ff5bd599bfe4;
extern _jc_method _jc_java_net_InetSocketAddress$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_net_InetSocketAddress$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_net_InetSocketAddress$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_net_InetAddress$object	*(*getAddress$1fb94530641aa9d0)(_jc_env *, struct _jc_java_net_InetSocketAddress$object *);
	struct _jc_java_lang_String$object	*(*getHostName$668f39cc56f1375b)(_jc_env *, struct _jc_java_net_InetSocketAddress$object *);
	jint	(*getPort$e10115a3e6b3cead)(_jc_env *, struct _jc_java_net_InetSocketAddress$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_net_InetSocketAddress$object *);
	jboolean	(*isUnresolved$3cc3ff5bd599bfe4)(_jc_env *, struct _jc_java_net_InetSocketAddress$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_net_InetSocketAddress$object *);
};

// Vtable
struct _jc_java_net_InetSocketAddress$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_SocketAddress$vmethods	java_net_SocketAddress;
	_jc_java_net_InetSocketAddress$vmethods	java_net_InetSocketAddress;
};

// Vtype
struct _jc_java_net_InetSocketAddress$vtype {
	_jc_type			type;
	_jc_java_net_InetSocketAddress$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_InetSocketAddress$sub_refs {
	struct _jc_java_lang_String$object	*hostname;
	struct _jc_java_net_InetAddress$object	*addr;
};

// Reference instance fields (object)
struct _jc_java_net_InetSocketAddress$refs {
    _jc_java_net_InetSocketAddress$sub_refs	java_net_InetSocketAddress;
    _jc_java_net_SocketAddress$sub_refs	java_net_SocketAddress;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_InetSocketAddress$sub_nonrefs {
	jint	port;
};

// Non-reference instance fields (object)
struct _jc_java_net_InetSocketAddress$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_SocketAddress$sub_nonrefs	java_net_SocketAddress;
    _jc_java_net_InetSocketAddress$sub_nonrefs	java_net_InetSocketAddress;
};

// Object instance structure
struct _jc_java_net_InetSocketAddress$object {
	_jc_java_net_InetSocketAddress$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_InetSocketAddress$vtype	*vtype;
	_jc_java_net_InetSocketAddress$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_InetSocketAddress$vtype _jc_java_net_InetSocketAddress$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_InetSocketAddress, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_InetSocketAddress$class_object;

#endif	/* _JC_java_net_InetSocketAddress_H_ */

==> jc-1.4.6.tar.gz: java/net/InetSocketAddress.h <==
// public class java.net.InetSocketAddress

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a431c217c7840ef0 java_net_InetSocketAddress
// @dep_class 45e49f95a1f57a78 java_net_SocketAddress

// header file dependencies
// @dep_header java_net_SocketAddress

#include "java/net/SocketAddress.h"

#ifndef _JC_java_net_InetSocketAddress_H_
#define _JC_java_net_InetSocketAddress_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_InetAddress$object;

// Typedefs
typedef struct _jc_java_net_InetSocketAddress$sub_refs	_jc_java_net_InetSocketAddress$sub_refs;
typedef struct _jc_java_net_InetSocketAddress$sub_nonrefs	_jc_java_net_InetSocketAddress$sub_nonrefs;
typedef struct _jc_java_net_InetSocketAddress$refs	_jc_java_net_InetSocketAddress$refs;
typedef struct _jc_java_net_InetSocketAddress$nonrefs	_jc_java_net_InetSocketAddress$nonrefs;
typedef struct _jc_java_net_InetSocketAddress$object	_jc_java_net_InetSocketAddress$object;

typedef struct _jc_java_net_InetSocketAddress$fields_struct	_jc_java_net_InetSocketAddress$fields_struct;
typedef const struct _jc_java_net_InetSocketAddress$vmethods	_jc_java_net_InetSocketAddress$vmethods;
typedef const struct _jc_java_net_InetSocketAddress$vtable	_jc_java_net_InetSocketAddress$vtable;
typedef const struct _jc_java_net_InetSocketAddress$vtype	_jc_java_net_InetSocketAddress$vtype;

// Class fields structure
struct _jc_java_net_InetSocketAddress$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_net_InetSocketAddress$fields_struct _jc_java_net_InetSocketAddress$class_fields;

// Constructors
extern void _jc_java_net_InetSocketAddress$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_net_InetSocketAddress$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_net_InetSocketAddress$method$_init$8b03e78e1eb3b29e(_jc_env *, struct _jc_java_net_InetSocketAddress$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_net_InetSocketAddress$method$_init$0cb3d434db3c104e(_jc_env *, struct _jc_java_net_InetSocketAddress$object *, struct _jc_java_net_InetAddress$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_net_InetSocketAddress$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_net_InetSocketAddress$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_net_InetAddress$object *_jc_java_net_InetSocketAddress$method$getAddress$1fb94530641aa9d0(_jc_env *, struct _jc_java_net_InetSocketAddress$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_net_InetSocketAddress$method$getHostName$668f39cc56f1375b(_jc_env *, struct _jc_java_net_InetSocketAddress$object *) _JC_JCNI_ATTR;
extern jint _jc_java_net_InetSocketAddress$method$getPort$e10115a3e6b3cead(_jc_env *, struct _jc_java_net_InetSocketAddress$object *) _JC_JCNI_ATTR;
extern jint _jc_java_net_InetSocketAddress$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_net_InetSocketAddress$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_net_InetSocketAddress$method$isUnresolved$3cc3ff5bd599bfe4(_jc_env *, struct _jc_java_net_InetSocketAddress$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_net_InetSocketAddress$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_net_InetSocketAddress$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_net_InetSocketAddress$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_net_InetSocketAddress$method_info$getAddress$1fb94530641aa9d0;
extern _jc_method _jc_java_net_InetSocketAddress$method_info$getHostName$668f39cc56f1375b;
extern _jc_method _jc_java_net_InetSocketAddress$method_info$getPort$e10115a3e6b3cead;
extern _jc_method _jc_java_net_InetSocketAddress$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_net_InetSocketAddress$method_info$isUnresolved$3cc3ff5bd599bfe4;
extern _jc_method _jc_java_net_InetSocketAddress$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_net_InetSocketAddress$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_net_InetSocketAddress$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_net_InetAddress$object	*(*getAddress$1fb94530641aa9d0)(_jc_env *, struct _jc_java_net_InetSocketAddress$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getHostName$668f39cc56f1375b)(_jc_env *, struct _jc_java_net_InetSocketAddress$object *) _JC_JCNI_ATTR;
	jint	(*getPort$e10115a3e6b3cead)(_jc_env *, struct _jc_java_net_InetSocketAddress$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_net_InetSocketAddress$object *) _JC_JCNI_ATTR;
	jboolean	(*isUnresolved$3cc3ff5bd599bfe4)(_jc_env *, struct _jc_java_net_InetSocketAddress$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_net_InetSocketAddress$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_net_InetSocketAddress$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_SocketAddress$vmethods	java_net_SocketAddress;
	_jc_java_net_InetSocketAddress$vmethods	java_net_InetSocketAddress;
};

// Vtype
struct _jc_java_net_InetSocketAddress$vtype {
	_jc_type			type;
	_jc_java_net_InetSocketAddress$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_InetSocketAddress$sub_refs {
	struct _jc_java_lang_String$object	*hostname;
	struct _jc_java_net_InetAddress$object	*addr;
};

// Reference instance fields (object)
struct _jc_java_net_InetSocketAddress$refs {
    _jc_java_net_InetSocketAddress$sub_refs	java_net_InetSocketAddress;
    _jc_java_net_SocketAddress$sub_refs	java_net_SocketAddress;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_InetSocketAddress$sub_nonrefs {
	jint	port;
};

// Non-reference instance fields (object)
struct _jc_java_net_InetSocketAddress$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_SocketAddress$sub_nonrefs	java_net_SocketAddress;
    _jc_java_net_InetSocketAddress$sub_nonrefs	java_net_InetSocketAddress;
};

// Object instance structure
struct _jc_java_net_InetSocketAddress$object {
	_jc_java_net_InetSocketAddress$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_InetSocketAddress$vtype	*vtype;
	_jc_java_net_InetSocketAddress$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_InetSocketAddress$vtype _jc_java_net_InetSocketAddress$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_InetSocketAddress, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_InetSocketAddress$class_object;

#endif	/* _JC_java_net_InetSocketAddress_H_ */
